@@ -33,12 +33,15 @@
 #include <QJsonArray>
 #include <QMap>
 #include <QString>
+#include <QUrl>
 #include <QVariant>
 
+class QDir;
+
 namespace Tiled {
 
 struct FilePath {
-    QString absolutePath;
+    QUrl url;
 };
 
 /**
@@ -113,6 +116,9 @@ TILEDSHARED_EXPORT int nameToType(const QString &name);
 TILEDSHARED_EXPORT QVariant toExportValue(const QVariant &value);
 TILEDSHARED_EXPORT QVariant fromExportValue(const QVariant &value, int type);
 
+TILEDSHARED_EXPORT QVariant toExportValue(const QVariant &value, const QDir &dir);
+TILEDSHARED_EXPORT QVariant fromExportValue(const QVariant &value, int type, const QDir &dir);
+
 } // namespace Tiled
 
 Q_DECLARE_METATYPE(Tiled::FilePath)
